import type { Api, EndpointDefinitions } from '@reduxjs/toolkit/query';
import type { QueryKeys } from '@reduxjs/toolkit/dist/query/core/apiState';
import type { CoreModule, PrefetchOptions } from '@reduxjs/toolkit/dist/query/core/module';
import type { SerializeQueryArgs } from '@reduxjs/toolkit/dist/query/defaultSerializeQueryArgs';
import { ApiContext } from '@reduxjs/toolkit/dist/query/apiTypes';
import type { AngularHooksModuleOptions } from './module';
import type { QueryHooks, UseMutation } from './types';
/**
 *
 * @param opts.api - An API with defined endpoints to create hooks for
 * @param opts.moduleOptions.useDispatch - The version of the `useDispatch` hook to be used
 * @param opts.moduleOptions.useSelector - The version of the `useSelector` hook to be used
 * @returns An object containing functions to generate hooks based on an endpoint
 */
export declare function buildHooks<Definitions extends EndpointDefinitions>({ api, moduleOptions: { useDispatch: dispatch, useSelector }, serializeQueryArgs, context, }: {
    api: Api<any, Definitions, any, any, CoreModule>;
    moduleOptions: Required<AngularHooksModuleOptions>;
    serializeQueryArgs: SerializeQueryArgs<any>;
    context: ApiContext<Definitions>;
}): {
    buildQueryHooks: (name: string) => QueryHooks<any>;
    buildMutationHook: (name: string) => UseMutation<any>;
    usePrefetch: <EndpointName extends QueryKeys<Definitions>>(endpointName: EndpointName, defaultOptions?: PrefetchOptions) => (arg: any, options?: PrefetchOptions) => void;
};
